Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(429)

Unified Diff: remoting/host/it2me/it2me_host.h

Issue 2724223003: Disconnect all users if too many connection requests are received for It2Me (Closed)
Patch Set: Fixing another non-Windows build error Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | remoting/host/it2me/it2me_host.cc » ('j') | remoting/host/it2me/it2me_host.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/it2me/it2me_host.h
diff --git a/remoting/host/it2me/it2me_host.h b/remoting/host/it2me/it2me_host.h
index 964f911eb6179c222b853d14e5671126607d643f..efeb6428f0e64eee0a95115fdd8f04442c89ef60 100644
--- a/remoting/host/it2me/it2me_host.h
+++ b/remoting/host/it2me/it2me_host.h
@@ -98,10 +98,15 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
void SetPolicyForTesting(std::unique_ptr<base::DictionaryValue> policies,
const base::Closure& done_callback);
// Returns the callback used for validating the connection. Do not run the
// returned callback after this object has been destroyed.
protocol::ValidatingAuthenticator::ValidationCallback
- GetValidationCallbackForTesting();
+ GetIncomingConnectionCallbackForTesting();
+
+ // Returns the callback used for validating accepted connections.
+ // Do not run the returned callback after this object has been destroyed.
+ protocol::ValidatingAuthenticator::ValidationCallback
+ GetAcceptedConnectionCallbackForTesting();
protected:
friend class base::RefCountedThreadSafe<It2MeHost>;
@@ -153,6 +158,11 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
const std::string& remote_jid,
const protocol::ValidatingAuthenticator::ResultCallback& result_callback);
+ // Allows the user to accept or reject the connection before it is completed.
+ void ShowConfirmationDialog(
+ const std::string& remote_jid,
+ const protocol::ValidatingAuthenticator::ResultCallback& result_callback);
+
// Caller supplied fields.
std::unique_ptr<ChromotingHostContext> host_context_;
base::WeakPtr<It2MeHost::Observer> observer_;
@@ -193,10 +203,6 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
// variable contains the thunk if it is necessary.
base::Closure pending_connect_;
- // Called after the client machine initiates the connection process and
- // determines whether to reject the connection or allow it to continue.
- protocol::ValidatingAuthenticator::ValidationCallback validation_callback_;
-
DISALLOW_COPY_AND_ASSIGN(It2MeHost);
};
« no previous file with comments | « no previous file | remoting/host/it2me/it2me_host.cc » ('j') | remoting/host/it2me/it2me_host.cc » ('J')
@@ -98,10 +98,15 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
void SetPolicyForTesting(std::unique_ptr<base::DictionaryValue> policies,
const base::Closure& done_callback);
- // Returns the callback used for validating the connection. Do not run the
- // returned callback after this object has been destroyed.
+ // Returns the callback used for validating incoming connections.
+ // Do not run the returned callback after this object has been destroyed.
protocol::ValidatingAuthenticator::ValidationCallback

Powered by Google App Engine
This is Rietveld 408576698